@@ -91,7 +91,10 @@ indiv_ctstm_sim_disease <- function(trans_model, max_t = 100, max_age = 100,
                                  trans_model$start_age,
                                  rep(0, trans_model$input_data$n_patients), # Start time is always 0
                                  trans_model$death_state - 1, 
-                                 trans_model$clock, trans_model$reset_states - 1,
+                                 trans_model$clock,
+                                 trans_model$reset_states - 1,
+                                 ## must match `enum TransitionTypes` in indiv-ctstm.h
+                                 match(trans_model$transition_types, c("reset","time","age")) - 1L,
                                  max_t, max_age, progress)
   disprog <- data.table(disprog)
   disprog[, sample := sample + 1]
@@ -234,11 +237,13 @@ IndivCtstmTrans <- R6::R6Class(
     death_state = NULL,
     
     #' @field clock "reset" for a clock-reset model, "forward" for a clock-forward model, 
-    #' and "mix" for a mixture of clock-reset and clock-forward models. A clock-reset model 
+    #' "mix" for a mixture of clock-reset and clock-forward models by state, and
+    #' "mixt" for a mixture of clock-reset and clock-forward models by transition. A clock-reset model 
     #' is a semi-Markov model in which transition rates depend on time since entering a state. 
     #' A clock-forward model is a Markov model in which transition rates depend on time 
     #' since entering the initial state. If `"mix"` is used, then 
-    #' `reset_states` must be specified.
+    #' `reset_states` must be specified. If `"mixt"` is used, then `transition_types` must
+    #' be specified.
     clock = NULL,
     
     #' @field reset_states A vector denoting the states in which time resets. 
@@ -247,6 +252,13 @@ IndivCtstmTrans <- R6::R6Class(
     #' `clock = "mix"`.
     reset_states = NULL,
     
+    #' @field transition_types A vector denoting the type of transition.
+    #' The vector is of the same length as the number of transitions
+    #' and takes values `"reset"`, `"time"` or `"age"` for hazards that are functions of
+    #' reset time, time since study entry or age, respectively. Only used if
+    #' `clock = "mixt"`.
+    transition_types = NULL,
+    
     #' @description
     #' Create a new `IndivCtstmTrans` object.
     #' @param params The `params` field.
@@ -257,13 +269,15 @@ IndivCtstmTrans <- R6::R6Class(
     #' @param death_state The `death_state` field.
     #' @param clock The `clock` field.
     #' @param reset_states The `reset_states` field.
+    #' @param transition_types The `transition_types` field.
     #' @return A new `IndivCtstmTrans` object.    
     initialize = function(params, input_data, trans_mat, 
                           start_state = 1,
                           start_age = 38,
                           death_state = NULL,
-                          clock = c("reset", "forward", "mix"),
-                          reset_states = NULL) {
+                          clock = c("reset", "forward", "mix", "mixt"),
+                          reset_states = NULL,
+                          transition_types = NULL) {
       self$params <- params
       self$input_data <- input_data
       self$trans_mat <- trans_mat
@@ -273,6 +287,15 @@ IndivCtstmTrans <- R6::R6Class(
       } else{
         self$reset_states <- reset_states
       }
+      if (is.null(transition_types)){
+        self$transition_types <- vector(mode = "double")
+      } else{
+        all_transition_types = c("reset", "time", "age")
+        self$transition_types <-
+            all_transition_types[pmatch(transition_types, all_transition_types, NA, TRUE)]
+        stopifnot(all(self$transition_types %in% all_transition_types),
+                  is.null(trans_mat) || length(self$transition_types) == max(trans_mat, na.rm=TRUE))
+      }
       
       # history
       self$start_state <- private$check_history(start_state)
@@ -351,10 +374,13 @@ IndivCtstmTrans <- R6::R6Class(
 #' [`expand.hesim_data`].
 #' @param trans_mat The transition matrix describing the states and transitions in a 
 #' multi-state model in the format from the [`mstate`][mstate::mstate] package. See [`IndivCtstmTrans`].
-#' @param clock "reset" for a clock-reset model, "forward" for a clock-forward model, and "mix" for a mixture
+#' @param clock "reset" for a clock-reset model, "forward" for a clock-forward model,
+#' "mix" for a mixture by state, and "mixt" for a mixture by transition
 #' of clock-reset and clock-forward models. See the field `clock` in [`IndivCtstmTrans`].
 #' @param reset_states A vector denoting the states in which time resets. See the field 
 #' `reset_states` in [`IndivCtstmTrans`].
+#' @param transition_types A vector denoting the type for each transition. See the field
+#' `transition_types` in [`IndivCtstmTrans`].
 #' @inheritParams create_CohortDtstmTrans
 #' @param ... Further arguments passed to `IndivCtstmTrans$new()` in [`IndivCtstmTrans`].
 #' @return Returns an [`R6Class`] object of class [`IndivCtstmTrans`].
@@ -423,21 +449,25 @@ create_IndivCtstmTrans.flexsurvreg <- function(object, input_data, trans_mat, cl
 #' @export
 #' @rdname create_IndivCtstmTrans
 create_IndivCtstmTrans.params_surv <- function(object, input_data, trans_mat, 
-                                               clock = c("reset", "forward", "mix"),
-                                               reset_states = NULL,...){
+                                               clock = c("reset", "forward", "mix", "mixt"),
+                                               reset_states = NULL, transition_types = NULL,
+                                               ...){
   input_mats <- create_input_mats(object, input_data)
   return(IndivCtstmTrans$new(input_data = input_mats, params = object, trans_mat = trans_mat,
-                             clock = match.arg(clock), reset_states = reset_states, ...))
+                             clock = match.arg(clock), reset_states = reset_states,
+                             transition_types = transition_types, ...))
 }
 
 #' @export
 #' @rdname create_IndivCtstmTrans
 create_IndivCtstmTrans.params_surv_list <- function(object, input_data, trans_mat, 
-                                                    clock = c("reset", "forward", "mix"),
-                                                    reset_states = NULL,...){
+                                                    clock = c("reset", "forward", "mix", "mixt"),
+                                                    reset_states = NULL,
+                                                    transition_types = NULL, ...){
   input_mats <- create_input_mats(object, input_data)
   return(IndivCtstmTrans$new(input_data = input_mats, params = object, trans_mat = trans_mat,
-                             clock = match.arg(clock), reset_states = reset_states, ...))
+                             clock = match.arg(clock), reset_states = reset_states,
+                             transition_types = transition_types, ...))
 }
 
 # IndivCtstm class -------------------------------------------------------------
